Learn R Programming

fftab (version 0.1.0)

.as_fftab_obj: Build a FFTAB Object

Description

Converts an object into a fftab object with additional metadata attributes.

Usage

.as_fftab_obj(x, .is_normalized, .is_complex, ...)

Value

The input object x, with the fftab class and any additional attributes provided in ....

Arguments

x

The input object to convert, typically a tibble or data frame.

.is_normalized

A logical value indicating if the input is normalized.

.is_complex

A logical value indicating if the original data was complex.

...

Additional attributes to include in the structured object, such as metadata or specific attributes required for Fourier Transform analysis.