Learn R Programming

fftab (version 0.1.0)

.fft: Compute the Fast Fourier Transform (FFT) of a Vector

Description

Computes the Fast Fourier Transform (FFT) of a numeric vector. Optionally, normalizes the result by dividing it by the length of the input vector.

Usage

.fft(x, norm = FALSE)

Value

A complex vector representing the FFT of the input signal.

Arguments

x

A numeric vector representing the input signal to transform.

norm

A logical value indicating whether to normalize the FFT output by dividing it by the length of the input vector. Default is FALSE.

Details

This function wraps around the base R stats::fft function and provides an option for normalization.

See Also