Learn R Programming

fftab (version 0.1.0)

.fourier_frequencies: Compute Fourier frequencies for default inputs

Description

Computes normalized Fourier frequencies for scalar or vector inputs, which are evenly spaced between -0.5 and 0.5.

Usage

.fourier_frequencies(x)

Value

A numeric vector containing the normalized Fourier frequencies.

Arguments

x

A scalar or vector representing the length of the sequence.