Learn R Programming

fftab (version 0.1.0)

.get_dim_cols: Select Columns Starting with .dim_

Description

Selects columns from a data frame whose names start with .dim_.

Usage

.get_dim_cols(x)

Value

A data frame containing only the columns that start with .dim_.

Arguments

x

A data frame or tibble from which to select columns.