Learn R Programming

fftab (version 0.1.0)

fft_internal_filters: Remove DC Component and Symmetric Frequencies

Description

Internal functions to manipulate and filter Fourier coefficients in fftab objects.

Usage

.remove_dc(x)

.remove_symmetric(x)

.split_symmetric(x)

Value

A fftab object with filtered coefficients.

Arguments

x

A fftab object containing Fourier coefficients and associated metadata.

Details

  • .remove_dc(): Filters out rows where all .dim_* columns have a value of 0.

  • .remove_symmetric():

    • For real-valued signals, it filters out redundant, complex-conjugate frequencies.

    • For complex-valued signals, no filtering is applied as symmetry isn't relevant.

  • .split_symmetric(): Splits the coefficients into symmetric and asymmetric parts.

See Also