Converts an object into a fftab object with additional metadata attributes.
.as_fftab_obj(x, .is_normalized, .is_complex, ...)The input object x, with the fftab class and any additional
attributes provided in ....
The input object to convert, typically a tibble or data frame.
A logical value indicating if the input is normalized.
A logical value indicating if the original data was complex.
Additional attributes to include in the structured object, such as metadata or specific attributes required for Fourier Transform analysis.