powered by
Computes normalized Fourier frequencies for scalar or vector inputs, which are evenly spaced between -0.5 and 0.5.
.fourier_frequencies(x)
A numeric vector containing the normalized Fourier frequencies.
A scalar or vector representing the length of the sequence.