powered by
.dim_
Selects columns from a data frame whose names start with .dim_.
.get_dim_cols(x)
A data frame containing only the columns that start with .dim_.
A data frame or tibble from which to select columns.