Internal functions to manipulate and filter Fourier coefficients in fftab objects.
.remove_dc(x).remove_symmetric(x)
.split_symmetric(x)
A fftab object with filtered coefficients.
A fftab object containing Fourier coefficients and associated metadata.
.remove_dc(): Filters out rows where all .dim_* columns have a value of 0.
.remove_symmetric():
For real-valued signals, it filters out redundant, complex-conjugate frequencies.
For complex-valued signals, no filtering is applied as symmetry isn't relevant.
.split_symmetric(): Splits the coefficients into symmetric and asymmetric parts.
fftab()